==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/corelibs/U2Algorithm/src/msa_alignment/AlignSequencesToAlignmentTaskSettings.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_ALIGN_SEQUENCES_TO_ALIGNMENT_TASK_SETTINGS_H_
#define _U2_ALIGN_SEQUENCES_TO_ALIGNMENT_TASK_SETTINGS_H_

#include "AbstractAlignmentTask.h"

namespace U2 {

class U2ALGORITHM_EXPORT AlignSequencesToAlignmentTaskSettings : public AbstractAlignmentTaskSettings {
public:
    AlignSequencesToAlignmentTaskSettings();
    AlignSequencesToAlignmentTaskSettings(const U2EntityRef &msaRef, const U2AlphabetId &newAlphabet, bool addAsFragments = false);
    AlignSequencesToAlignmentTaskSettings(const AlignSequencesToAlignmentTaskSettings &s);

    virtual bool isValid() const;

    QList<U2EntityRef> addedSequencesRefs;
    QStringList addedSequencesNames;
    bool addAsFragments;
    bool reorderSequences;
    int referenceRowId;
    qint64 maxSequenceLength;
};
}  // namespace U2

#endif  // _U2_PAIRWISE_ALIGNMENT_TASK_H_

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/corelibs/U2Algorithm/src/msa_alignment/AlignSequencesToAlignmentTaskSettings.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include "AbstractAlignmentTask.h"

namespace U2 {

class U2ALGORITHM_EXPORT AlignSequencesToAlignmentTaskSettings : public AbstractAlignmentTaskSettings {
public:
    AlignSequencesToAlignmentTaskSettings();
    AlignSequencesToAlignmentTaskSettings(const U2EntityRef& msaRef, const U2AlphabetId& newAlphabet, bool addAsFragments = false);
    AlignSequencesToAlignmentTaskSettings(const AlignSequencesToAlignmentTaskSettings& s);

    virtual bool isValid() const;

    QList<U2EntityRef> addedSequencesRefs;
    QStringList addedSequencesNames;
    bool addAsFragments;
    bool reorderSequences;
    int referenceRowId;
    qint64 maxSequenceLength;
};
}  // namespace U2
